from os import environ

from pytest import fixture

from chatnoir_api import Index

from chatnoir_pyterrier.retrieve import Feature


@fixture(scope="module")
def api_key() -> str:
    if "CHATNOIR_API_KEY" not in environ:
        raise RuntimeError(
            "Must specify ChatNoir api key "
            "in the CHATNOIR_API_KEY environment variable "
            "to run this test."
        )
    return environ["CHATNOIR_API_KEY"]


@fixture(scope="module", params=["python library", "search engine"])
def query(request) -> str:
    return request.param


@fixture(
    scope="module",
    params=[Index.ClueWeb09, Index.ClueWeb12, Index.CommonCrawl1511]
)
def index(request) -> Index:
    return request.param


@fixture(scope="module", params=[feature for feature in Feature])
def feature(request) -> Feature:
    return request.param



from enum import unique, auto, Flag


@unique
class Feature(Flag):
    NONE = 0
    UUID = auto()
    INDEX = auto()
    TARGET_HOSTNAME = auto()
    TARGET_URI = auto()
    TARGET = TARGET_HOSTNAME | TARGET_URI
    PAGE_RANK = auto()
    SPAM_RANK = auto()
    RANKS = PAGE_RANK | SPAM_RANK
    TITLE_HIGHLIGHTED = auto()
    TITLE_TEXT = auto()
    TITLE = TITLE_HIGHLIGHTED | TITLE_TEXT
    SNIPPET_HIGHLIGHTED = auto()
    SNIPPET_TEXT = auto()
    SNIPPET = SNIPPET_HIGHLIGHTED | SNIPPET_TEXT
    EXPLANATION = auto()
    HTML = auto()
    HTML_PLAIN = auto()
    ALL = (
            UUID | INDEX | TARGET | RANKS | TITLE | SNIPPET | EXPLANATION |
            HTML | HTML_PLAIN
    )



__version__ = "1.0.2"

from logging import getLogger

from chatnoir_pyterrier import retrieve, feature

logger = getLogger("chatnoir-pyterrier")

# Re-export from child modules.
Feature = feature.Feature
ChatNoirRetrieve = retrieve.ChatNoirRetrieve
